@@ -67,8 +67,21 @@ def get_sphinx_args(sconf, conf):
     o.append('-b {0}'.format(sconf.builder))
 
     if is_parallel_sphinx(pkg_resources.get_distribution("sphinx").version):
-        if 'serial_sphinx' in conf.runstate and conf.runstate.serial_sphinx is True:
-            pass
+        if 'serial_sphinx' in conf.runstate:
+            if conf.runstate.serial_sphinx == "publish":
+                if ((len(conf.runstate.builder) >= 1 or 'publish' in conf.runstate.builder) or
+                    len(conf.runstate.languages_to_build) >= 1 or
+                    len(conf.runstate.editions_to_build) >= 1):
+                    pass
+                else:
+                    o.append(' '.join( [ '-j', str(cpu_count()) ]))
+            elif conf.runstate.serial_sphinx is False:
+                o.append(' '.join( [ '-j', str(cpu_count()) ]))
+            elif (isinstance(conf.runstate.serial_sphinx, (int, long, float)) and
+                  conf.runstate.serial_sphinx > 1):
+                o.append(' '.join(['-j', str(conf.runstate.serial_sphinx)]))
+            else:
+                pass
         else:
             o.append(' '.join( [ '-j', str(cpu_count()) ]))
 
